#
# spec file for package python-qt5-sip
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-qt5-sip
Version:        12.13.0
Release:        2.2
License:        GPL-2.0-only OR GPL-3.0-only OR SUSE-SIP
Summary:        The sip module support for PyQt5
URL:            https://www.riverbankcomputing.com/software/sip/
Group:          Development/Languages/Python
Source0:        https://files.pythonhosted.org/packages/source/P/PyQt5-sip/PyQt5_sip-%{version}.tar.gz
Patch0:         fix-build-gcc14.patch
Patch100:       support-python3.6.patch
BuildRequires:  %{python_module devel >= 3.6}
BuildRequires:  %{python_module setuptools >= 30.3}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Provides:       python-PyQt5-sip = %{version}-%{release}

%python_subpackages

%description
The sip extension module provides support for the PyQt5 package.

SIP is a tool that makes it very easy to create Python bindings for
C and C++ libraries. It was originally developed to create PyQt,
the Python bindings for the Qt toolkit, but can be used to create
bindings for any C or C++ library. For example, it is also used to
create wxPython, the Python bindings for the wxWidget toolkit.

%prep
%autosetup -p1 -n PyQt5_sip-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%files %{python_files}
%license LICENSE LICENSE-GPL2 LICENSE-GPL3
%dir %{python_sitearch}/PyQt5
%{python_sitearch}/PyQt5/sip*
%{python_sitearch}/PyQt5_sip-%{version}*info

%changelog
* Thu Mar  7 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Add fix-build-gcc14.patch to fix build with GCC14 (boo#1221016)
- Switch to %%autosetup
* Sun Oct 15 2023 Ben Greiner <code@bnavigator.de>
- Update to 12.13.0
  * Added sipPyTypeDictRef() to the v12 and v13 ABIs.
    sipPyTypeDict() is now deprecated and must not be used with
    Python v3.12 and later.
  * Classes will automatically support being iterated over if they
    implement '__getitem__()' or 'operator[]' and have a method
    annotated with '__len__'.
  * Bug fixes.
* Wed Sep 27 2023 Ben Greiner <code@bnavigator.de>
- Update to ABI version 12.12.2
  * Match python-sip6-devel 6.7.10+
* Sat Jun 10 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Mon Apr 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 12.12.1
  * Fixed the new handling of ctors with /Transfer/ annotated
    arguments.
* Sun Jan 29 2023 Ben Greiner <code@bnavigator.de>
- Update to ABI version 12.11.1
  * error on subclassing enums
* Thu Jan 12 2023 Antonio Larrosa <alarrosa@suse.com>
- Add patch to revert the drop of support for python 3.6:
  * support-python3.6.patch
* Mon Jun 20 2022 Ben Greiner <code@bnavigator.de>
- Update to ABI version 12.11.0
  * The array type is now accessible from the sip module.
* Wed Apr 13 2022 Ben Greiner <code@bnavigator.de>
- Update to ABI version 12.10.1
- Support for Python 3.6 has been dropped
* Fri Jun 18 2021 Ben Greiner <code@bnavigator.de>
- Provide the PyPI name
* Thu May 13 2021 Ben Greiner <code@bnavigator.de>
- Update to 12.9.0
  * no release notes, new ABI version.
* Sun Aug 30 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 12.8.1
  * minor bugfix release
* Fri Aug 28 2020 Benjamin Greiner <code@bnavigator.de>
- Initial specfile for version 12.8.0
  Quote from https://www.riverbankcomputing.com/static/Docs/PyQt5/installation.html#building-the-sip-module
  It is not necessary to install the PyQt5.sip module before
  building PyQt5 but it must be installed before PyQt5 can be used.
